using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;

namespace FiveChess
{
    public delegate void GameEventHandler(object sender,GameEventArgs e);
    [Serializable]
    public class GameEventArgs : EventArgs
    {
        public readonly Result Result;
        public readonly Stack<Point> History;
        public readonly Player[,] CheckerBoard;
        public GameEventArgs(Result r, Stack<Point> history, Player[,] checkerBoard)
        {
            Result = r;
            History = history;
            CheckerBoard = checkerBoard;
        }
    }

    #region Enums

    public enum Player { White=1, Black=2, None=0 }
    public enum Command
    {
        Join, Quit, Play
    }
    public enum Status
    {
        End, WaitingPlayer, Playing,
    }
    [Serializable]
    public struct Result
    {
        public Status Status;
        public Player Player;
    }

    #endregion
    public interface IGame
    {
        bool Play(Point step, Player player);
        void SetEventSinker(Player player,GameEventSinker sinker);
        Player Join();
    }

    public class GameEventSinker  : MarshalByRefObject 
    {
        public event GameEventHandler GameStatusChanged;
        public void RaiseEvent(object sender,GameEventArgs e)
        {
            if (this.GameStatusChanged != null)
                GameStatusChanged(null, e);
        }
    }
}
